@@ -3,7 +3,7 @@ BEGIN {
   $Catalyst::Model::MongoDB::AUTHORITY = 'cpan:GETTY';
 }
 {
-  $Catalyst::Model::MongoDB::VERSION = '0.11';
+  $Catalyst::Model::MongoDB::VERSION = '0.12';
 }
 # ABSTRACT: MongoDB model class for Catalyst
 use MongoDB;
@@ -19,6 +19,7 @@ has collectionname => ( isa => 'Str', is => 'ro' );
 has gridfsname     => ( isa => 'Str', is => 'ro' );
 has username       => ( isa => 'Str', is => 'ro', predicate => 'has_username' );
 has password       => ( isa => 'Str', is => 'ro', predicate => 'has_password' );
+has find_master    => ( isa => 'Int', is => 'ro', default => sub { 0 } );
 
 has 'connection' => (
   isa => 'MongoDB::MongoClient',
@@ -32,6 +33,7 @@ sub _build_connection {
   my $conn = MongoDB::MongoClient->new(
       host => $self->host,
       port => $self->port,
+      find_master => $self->find_master,
       ( $self->dbname ? ( dbname => $self->dbname ) : () ),
   );
 
@@ -155,7 +157,7 @@ Catalyst::Model::MongoDB - MongoDB model class for Catalyst
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
